/**
 * World.java
 * part of cellularAutomata
 *
 * written by Matthew Shanley
 * matthewshanley@littlesecretsrecords.com
 */

package com.littlesecretsrecords.cellularautomata;

import java.lang.*;

public class World {
    private int width;   // number of columns of sites
    private int height;   // number of rows of sites
    private Site[][] mySites;   // array of sites that make up the world
    private int numThoughtWords;   // number of ThoughtWords to distribute randomly at start
    private float xGradient;   // gradient in x direction encouraging beings to move in one direction or the other
    private float yGradient;   // gradient in y direction encouraging beings to move in one direction or the other

    // Constructor
    public World(int initWidth, int initHeight, int initNumThoughtWords) {
	this.width = initWidth;
	this.height = initHeight;
	mySites = new Site[this.width][this.height];
	for (int i=0; i<this.width; i++) {
	    for (int j=0; j<this.height; j++) {
		mySites[i][j] = new Site();
	    }
	}
	this.numThoughtWords = initNumThoughtWords;
	// Leave ThoughtWords in random positions
	String newThoughtWordType;
	int twXpos, twYpos;
	for (int i=0; i<numThoughtWords; i++) {
	    switch ((int)(Math.random()*2)) {
	    case 0: newThoughtWordType = "selfconscious"; break;
	    case 1: newThoughtWordType = "memory"; break;
	    default: System.out.println("Problem with Math.random in World constructor."); newThoughtWordType = "selfconscious"; break;
	    }
	    twXpos = (int)(Math.random()*width);
	    twYpos = (int)(Math.random()*height);
	    mySites[twXpos][twYpos].leaveThoughtWord(new ThoughtWord(newThoughtWordType));
	}
	this.xGradient = 0;
	this.yGradient = 0;
    }

    // Public Methods
    public int getWidth() {
	return this.width;
    }

    public int getHeight() {
	return this.height;
    }

    public Site getSite(int x, int y) {
	return mySites[x][y];
    }
    
    protected float getXgradient() {
	return xGradient;
    }

    protected float getYgradient() {
	return yGradient;
    }

    public void adjustXgradient(float adjustment) {
	xGradient = (float)Math.min(xGradient+adjustment, 0.25);
    }

    public void adjustYgradient(float adjustment) {
	yGradient = (float)Math.min(yGradient+adjustment, 0.25);
    }
}
